RmiiClockConfig

Trait RmiiClockConfig 

pub trait RmiiClockConfig: Sealed {
    // Required method
    fn configure(self);
}
Sealed trait implemented by all RMII clock configurations.

Required Methods

fn configure(self)

Configures the hardware for RMII, including the clock input/output GPIO pad.

Consumes self so that the pin carried inside the struct is configured and ownership is transferred to the peripheral.

Implementors

Source

impl<P: RmiiClkIn> RmiiClockConfig for ExternalRefClock<P>

Available on crate feature unstable only.
Source

impl<P: RmiiClkOut> RmiiClockConfig for ApllClock<P>

Available on crate feature unstable only.